==> restified-0.0.14.tar.gz: lib/crud.dart <==
library crud;

import 'package:flutter/foundation.dart';
import 'package:restified/http.dart';
import 'package:rxdart/rxdart.dart';

class GetBloc<T> {
  final String endpoint;
  final Serializable<T> model;

  final BehaviorSubject<List<T>> _all = BehaviorSubject<List<T>>();
  final BehaviorSubject<T> _single = BehaviorSubject<T>();
  final BehaviorSubject<bool> _loading = BehaviorSubject<bool>();

  GetBloc({@required this.endpoint, @required this.model}) {
    _single.sink.add(null);
    _all.sink.add(null);
    _loading.sink.add(true);
  }

  getAll() async {
    _loading.sink.add(true);
    List<T> response = await Http().getAll('$endpoint', model);
    _all.sink.add(response);
    _loading.sink.add(false);
  }

  getById(int id) async {
    _loading.sink.add(true);
    T m = await Http().getSingle('$endpoint/$id', model);
    _single.sink.add(m);
    _loading.sink.add(false);
  }

  dispose() {
    _all.close();
    _single.close();
    _loading.close();
  }

  BehaviorSubject<List<T>> get all => _all;

  BehaviorSubject<T> get single => _single;

  BehaviorSubject<bool> get loading => _loading;
}

class ManipulationBloc<T> {
  final String endpoint;
  final int id;

  final BehaviorSubject<T> _model = BehaviorSubject<T>();
  final BehaviorSubject<bool> _loading = BehaviorSubject<bool>();
  final BehaviorSubject<Response> _updateResponse = BehaviorSubject<Response>();
  final BehaviorSubject<Response> _insertResponse = BehaviorSubject<Response>();
  final BehaviorSubject<bool> _submitting = BehaviorSubject<bool>();

  Serializable<T> _m;

  ManipulationBloc(Serializable<T> model,
      {@required this.endpoint, @required this.id}) {
    _m = model;
    _model.sink.add(model.clone());
    _submitting.sink.add(false);
    fetch();
  }

  dispose() {
    _loading.close();
    _updateResponse.close();
    _insertResponse.close();
    _submitting.close();
    _model.close();
  }

  fetch() async {
    _loading.sink.add(true);
    if (id != null) {
      T m = await Http().getSingle('$endpoint/$id', _m);
      _model.sink.add(m);
    }
    _loading.sink.add(false);
  }

  update(int id, Map model) async {
    _submitting.sink.add(true);
    Response resp = await Http().put('$endpoint/$id', model);
    _updateResponse.sink.add(resp);
    _submitting.sink.add(false);
    fetch();
  }

  insert(Map model) async {
    _submitting.sink.add(true);
    Response resp = await Http().post('$endpoint', model);
    _insertResponse.sink.add(resp);
    _submitting.sink.add(false);
    fetch();
  }

  clearResponse() async {
    _updateResponse.sink.add(null);
    _insertResponse.sink.add(null);
  }

  BehaviorSubject<T> get model => _model;

  BehaviorSubject<bool> get loading => _loading;

  BehaviorSubject<Response> get updateResponse => _updateResponse;

  BehaviorSubject<Response> get insertResponse => _insertResponse;

  BehaviorSubject<bool> get submitting => _submitting;
}

==> restified-0.0.15.tar.gz: lib/crud.dart <==
library crud;

import 'package:flutter/foundation.dart';
import 'package:restified/http.dart';
import 'package:rxdart/rxdart.dart';

class GetBloc<T> {
  final String endpoint;
  final Serializable<T> model;

  final BehaviorSubject<List<T>> _all = BehaviorSubject<List<T>>();
  final BehaviorSubject<T> _single = BehaviorSubject<T>();
  final BehaviorSubject<bool> _loading = BehaviorSubject<bool>();

  GetBloc({@required this.endpoint, @required this.model}) {
    _single.sink.add(null);
    _all.sink.add(null);
    _loading.sink.add(true);
  }

  getAll() async {
    _loading.sink.add(true);
    List<T> response = await Http().getAll('$endpoint', model);
    _all.sink.add(response);
    _loading.sink.add(false);
  }

  getById(int id) async {
    _loading.sink.add(true);
    T m = await Http().getSingle('$endpoint/$id', model);
    _single.sink.add(m);
    _loading.sink.add(false);
  }

  dispose() {
    _all.close();
    _single.close();
    _loading.close();
  }

  BehaviorSubject<List<T>> get all => _all;

  BehaviorSubject<T> get single => _single;

  BehaviorSubject<bool> get loading => _loading;
}

class ManipulationBloc<T> {
  final String endpoint;
  final int id;

  final BehaviorSubject<T> _model = BehaviorSubject<T>();
  final BehaviorSubject<bool> _loading = BehaviorSubject<bool>();
  final BehaviorSubject<Response> _updateResponse = BehaviorSubject<Response>();
  final BehaviorSubject<Response> _insertResponse = BehaviorSubject<Response>();
  final BehaviorSubject<bool> _submitting = BehaviorSubject<bool>();

  Serializable<T> _m;

  ManipulationBloc(Serializable<T> model,
      {@required this.endpoint, @required this.id}) {
    _m = model;
    _model.sink.add(model.clone());
    _submitting.sink.add(false);
    fetch();
  }

  dispose() {
    _loading.close();
    _updateResponse.close();
    _insertResponse.close();
    _submitting.close();
    _model.close();
  }

  fetch() async {
    _loading.sink.add(true);
    if (id != null) {
      T m = await Http().getSingle('$endpoint/$id', _m);
      _model.sink.add(m);
    }
    _loading.sink.add(false);
  }

  update(int id, Serializable<T> model) async {
    _submitting.sink.add(true);
    Response resp = await Http().put('$endpoint/$id', model.toJson());
    _updateResponse.sink.add(resp);
    _submitting.sink.add(false);
    fetch();
  }

  insert(Serializable<T> model) async {
    _submitting.sink.add(true);
    Response resp = await Http().post('$endpoint', model.toJson());
    _insertResponse.sink.add(resp);
    _submitting.sink.add(false);
    fetch();
  }

  clearResponse() async {
    _updateResponse.sink.add(null);
    _insertResponse.sink.add(null);
  }

  BehaviorSubject<T> get model => _model;

  BehaviorSubject<bool> get loading => _loading;

  BehaviorSubject<Response> get updateResponse => _updateResponse;

  BehaviorSubject<Response> get insertResponse => _insertResponse;

  BehaviorSubject<bool> get submitting => _submitting;
}
